@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # This file is part of Xpra.
-# Copyright (C) 2019-2024 Antoine Martin <antoine@xpra.org>
+# Copyright (C) 2019 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -45,11 +45,13 @@ class FastMemoryConnection(Connection):
         if not self.read_buffers:
             logger = Logger("network")
             logger("read(%i) EOF", n)
+            time.sleep(0.1)
             return b""
         b = self.read_buffers[0]
         if len(b) <= n:
             return self.read_buffers.pop(0)
         self.read_buffers[0] = b[n:]
+        time.sleep(0.05)
         return b[:n]
 
     def write(self, buf, packet_type: str = "") -> int:
@@ -151,11 +153,14 @@ class ProtocolTest(unittest.TestCase):
             loop.quit()
 
         loop = GLib.MainLoop()
-        GLib.timeout_add(500, check_failed)
+        # we use a fake `tcp` connection, so the eof will call close() after 1000+500ms:
+        GLib.timeout_add(2500, check_failed)
         GLib.timeout_add(TIMEOUT*1000, loop.quit)
         proto.start()
         loop.run()
-        assert not errs, csv(errs)
+        if errs:
+            raise RuntimeError(f"test with input data {data!r} failed: %s" % csv(errs))
+        log("invalid data test ok for %r", data)
 
     def test_encoders_and_compressors(self) -> None:
         for encoder in ("rencodeplus", ):
@@ -246,7 +251,7 @@ class ProtocolTest(unittest.TestCase):
 
     def test_format_thread(self) -> None:
         packets = self.make_test_packets()
-        N = 1000
+        N = 10 if not SHOW_PERF else 1000
         many = self.repeat_list(packets, N)
 
         def get_packet_cb() -> tuple[PacketType, bool, bool]:
