@@ -1,15 +1,18 @@
 # This file is part of Xpra.
-# Copyright (C) 2010-2024 Antoine Martin <antoine@xpra.org>
+# Copyright (C) 2010 Antoine Martin <antoine@xpra.org>
 # Copyright (C) 2008 Nathaniel Smith <njs@pobox.com>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
+from typing import Final
+
 from xpra.os_util import gi_import
 from xpra.gtk.gobject import no_arg_signal, one_arg_signal
 from xpra.gtk.error import xlog, XError
+from xpra.x11.bindings.core import X11CoreBindings
 from xpra.x11.gtk.prop import raw_prop_set, raw_prop_get
 from xpra.x11.gtk.selection import ManagerSelection
-from xpra.x11.gtk.bindings import add_event_receiver, remove_event_receiver, get_pywindow, get_xatom
+from xpra.x11.gtk.bindings import add_event_receiver, remove_event_receiver, get_xatom
 from xpra.x11.xsettings_prop import bytes_to_xsettings, xsettings_to_bytes
 from xpra.log import Logger
 
@@ -19,10 +22,12 @@ GObject = gi_import("GObject")
 Gtk = gi_import("Gtk")
 Gdk = gi_import("Gdk")
 
+X11Core = X11CoreBindings()
+
 # the X11 atom name for the XSETTINGS property:
-XSETTINGS = "_XSETTINGS_SETTINGS"
+XSETTINGS: Final[str] = "_XSETTINGS_SETTINGS"
 # constant type in prop.py:
-XSETTINGS_TYPE = "xsettings-settings"
+XSETTINGS_TYPE: Final[str] = "xsettings-settings"
 
 XNone = 0
 
@@ -39,9 +44,8 @@ class XSettingsManager:
         # gone, the settings are gone. (Also, if we're stealing from
         # ourselves, we probably don't clean up the window properly.)
         self._manager.acquire(self._manager.FORCE_AND_RETURN)
-        self._window = self._manager.window()
 
-    def set_settings(self, settings):
+    def set_settings(self, settings) -> None:
         if isinstance(settings, list):
             settings = tuple(settings)
         elif not isinstance(settings, tuple):
@@ -49,7 +53,7 @@ class XSettingsManager:
             return
         try:
             data = xsettings_to_bytes(settings)
-            raw_prop_set(self._window.get_xid(), XSETTINGS, "_XSETTINGS_SETTINGS", 8, data)
+            raw_prop_set(self._manager.xid, XSETTINGS, "_XSETTINGS_SETTINGS", 8, data)
         except XError as e:
             log("set_settings(%s)", settings, exc_info=True)
             log.error("Error: XSettings not applied")
@@ -66,22 +70,22 @@ class XSettingsHelper:
         atom = Gdk.Atom.intern(self._selection, False)
         self._clipboard = Gtk.Clipboard.get(atom)
 
-    def xsettings_owner(self):
+    def xsettings_owner(self) -> int:
         with xlog:
             from xpra.x11.bindings.window import X11WindowBindings
             X11Window = X11WindowBindings()
             owner_x = X11Window.XGetSelectionOwner(self._selection)
             log("XGetSelectionOwner(%s)=%#x", self._selection, owner_x)
             if owner_x == XNone:
-                return None
-            return get_pywindow(owner_x)
+                return 0
+            return owner_x
 
     def get_settings(self):
         owner = self.xsettings_owner()
         log("Fetching current XSettings data, owner=%s", owner)
-        if owner is None:
+        if not owner:
             return None
-        data = raw_prop_get(owner.get_xid(), XSETTINGS, "_XSETTINGS_SETTINGS", ignore_errors=True, raise_xerrors=False)
+        data = raw_prop_get(owner, XSETTINGS, "_XSETTINGS_SETTINGS", ignore_errors=True, raise_xerrors=False)
         if data:
             return bytes_to_xsettings(data)
         return None
@@ -98,26 +102,25 @@ class XSettingsWatcher(XSettingsHelper, GObject.GObject):
     def __init__(self, screen_number=0):
         GObject.GObject.__init__(self)
         XSettingsHelper.__init__(self, screen_number)
-        root = self._clipboard.get_display().get_default_screen().get_root_window()
-        self.xid = root.get_xid()
+        self.xid = X11Core.get_root_xid()
         add_event_receiver(self.xid, self)
         self._add_watch()
 
-    def cleanup(self):
+    def cleanup(self) -> None:
         remove_event_receiver(self.xid, self)
 
-    def _add_watch(self):
+    def _add_watch(self) -> None:
         owner = self.xsettings_owner()
-        if owner is not None:
-            add_event_receiver(owner.get_xid(), self)
+        if owner:
+            add_event_receiver(owner, self)
 
-    def do_x11_client_message_event(self, evt):
+    def do_x11_client_message_event(self, evt) -> None:
         if evt.window is self.xid and evt.message_type == "MANAGER" and evt.data[1] == get_xatom(self._selection):
             log("XSettings manager changed")
             self._add_watch()
             self.emit("xsettings-changed")
 
-    def do_x11_property_notify_event(self, event):
+    def do_x11_property_notify_event(self, event) -> None:
         if str(event.atom) == XSETTINGS:
             log("XSettings property value changed")
             self.emit("xsettings-changed")
